@@ -11,8 +11,8 @@ nameEx("Fac.Num")
 flush(stderr()); flush(stdout())
 
 ### Name: Fac.Num
-### Title: Division of qualitative and quantitative variables.
-### Aliases: Fac.Num Fac.Num
+### Title: Division of qualitative and quantitative variables
+### Aliases: Fac.Num
 ### Keywords: multivariate
 
 ### ** Examples
@@ -120,8 +120,8 @@ nameEx("cluster.carac")
 flush(stderr()); flush(stdout())
 
 ### Name: cluster.carac
-### Title: Cluster Characterization by Variables.
-### Aliases: cluster.carac cluster.carac
+### Title: Cluster Characterization by Variables
+### Aliases: cluster.carac
 ### Keywords: multivariate hplot
 
 ### ** Examples
@@ -176,7 +176,7 @@ flush(stderr()); flush(stdout())
 
 ### Name: kmeansW
 ### Title: K-means with Weights of the Elements
-### Aliases: kmeansW kmeansW
+### Aliases: kmeansW
 ### Keywords: multivariate cluster
 
 ### ** Examples
@@ -200,7 +200,7 @@ flush(stderr()); flush(stdout())
 
 ### Name: list.to.data
 ### Title: list to data.frame
-### Aliases: list.to.data list.to.data
+### Aliases: list.to.data
 ### Keywords: multivariate
 
 ### ** Examples
@@ -218,14 +218,14 @@ flush(stderr()); flush(stdout())
 
 
 cleanEx()
-nameEx("planfac")
-### * planfac
+nameEx("plot.dudi")
+### * plot.dudi
 
 flush(stderr()); flush(stdout())
 
-### Name: planfac
-### Title: Correspondence Analysis Factorial Planes
-### Aliases: planfac sutil.grid
+### Name: plot.dudi
+### Title: Factorial Planes from Objects of Class dudi
+### Aliases: plot.dudi sutil.grid
 ### Keywords: multivariate hplot
 
 ### ** Examples
@@ -233,10 +233,10 @@ flush(stderr()); flush(stdout())
 data(ardeche)
 ca <- dudi.coa(ardeche$tab,scannf=FALSE,nf=4)
 # FactoMineR style
-planfac(ca,ucal=40,all.point=FALSE,titre="SCA of Ardeche, First Factorial Plane")
+plot.dudi(ca,ucal=40,all.point=FALSE,main="SCA of Ardeche, First Factorial Plane")
 dev.new()
 # ade4 style
-planfac(ca,x=3,y=4,ucal=20,all.point=FALSE,infaxes="in",titre="SCA of
+plot.dudi(ca,ex=3,ey=4,ucal=20,all.point=FALSE,infaxes="in",main="SCA of
 Ardeche, Plane 3-4")
 
 
@@ -262,12 +262,50 @@ Bog.ilu <- Bogota[ 1]
 
 FC.Bogota<-FactoClass(Bog.act, dudi.coa,Bog.ilu,nf=2,nfcl=5,k.clust=5,scanFC=FALSE)
 
-plotFactoClass(FC.Bogota,titre="Primer plano factorial del ACS de la TC de manzanas de Bogota",
+plotFactoClass(FC.Bogota,titre="First Factorial Plane from the SCA of Bogota's Blocks",
      col.row=c("maroon2","orchid4","darkgoldenrod2","dark red","aquamarine4"))
 
 
 
 
+cleanEx()
+nameEx("plotct")
+### * plotct
+
+flush(stderr()); flush(stdout())
+
+### Name: plotct
+### Title: Row and Column Profiles of a Contingency Table
+### Aliases: plotct
+### Keywords: hplot
+
+### ** Examples
+
+mycolors<-colors()[c(1,26,32,37,52,57,68,73,74,81,82,84,88,100)]
+data(Bogota)
+plotct(Bogota[,2:7],col=mycolors)
+
+
+
+cleanEx()
+nameEx("plotfp")
+### * plotfp
+
+flush(stderr()); flush(stdout())
+
+### Name: plotfp
+### Title: Factorial Planes from Coordinates
+### Aliases: plotfp
+### Keywords: multivariate hplot
+
+### ** Examples
+
+data(Bogota)
+ca <- dudi.coa(Bogota[,2:7],scannf=FALSE,nf=2)
+plotfp(ca$li,eig=ca$eig,main="First Factorial Plane")
+
+
+
 cleanEx()
 nameEx("stableclus")
 ### * stableclus
@@ -276,7 +314,7 @@ flush(stderr()); flush(stdout())
 
 ### Name: stableclus
 ### Title: Stable clusters for cluster analysis
-### Aliases: stableclus stableclus
+### Aliases: stableclus
 ### Keywords: multivariate cluster
 
 ### ** Examples
@@ -297,7 +335,7 @@ flush(stderr()); flush(stdout())
 
 ### Name: ward.cluster
 ### Title: Hierarchic Classification by Ward's Method
-### Aliases: ward.cluster ward.cluster
+### Aliases: ward.cluster
 ### Keywords: multivariate hplot
 
 ### ** Examples
